SystemOrganization addCategory: #'Phidget-EToys'!

!IconicButton methodsFor: '*Phidget-EToys' stamp: 'pt 5/7/2009 11:45'!
initializeWithThumbnail: aThumbnail withLabel: aLabel andColor: aColor andSend: aSelector to: aReceiver 	with: aPhidget
	"Initialize the receiver to show aThumbnail on its face, giving it the label supplied and arranging for it, when the button goes down on it, to obtain a new morph by sending the supplied selector to the supplied receiver"

	| labeledItem nonTranslucent |
	nonTranslucent := aColor asNontranslucentColor.
	labeledItem := AlignmentMorph newColumn.
	labeledItem color: nonTranslucent.
	labeledItem borderWidth: 0.
	labeledItem
		layoutInset: 4@0;
		cellPositioning: #center.
	labeledItem addMorph: aThumbnail.
	labeledItem addMorphBack: (Morph new extent: (4@4)) beTransparent.
	labeledItem addMorphBack: (TextMorph new
		backgroundColor: nonTranslucent;
		contentsAsIs: aLabel;
		beAllFont: Preferences standardEToysFont;
		centered).

	self
		beTransparent;
		labelGraphic: ((labeledItem imageForm: 32 backgroundColor: nonTranslucent forRectangle: labeledItem fullBounds) replaceColor: nonTranslucent withColor: Color transparent);
		borderWidth: 0;
		target: aReceiver;
		actionSelector: #launchPartVia:label:phidget:;
		arguments: {aSelector. aLabel. aPhidget};
		actWhen: #buttonDown.

	self stationarySetup.! !

!PolygonMorph class methodsFor: '*Phidget-EToys' stamp: 'lk 7/24/2009 14:27'!
createLineFrom: startPoint to: endPoint color: aColor width: aNumber

	^ self
		vertices: {startPoint. endPoint}
		color: aColor
		borderWidth: aNumber
		borderColor: aColor! !

PartsBin subclass: #PhdETPartsBin
	instanceVariableNames: 'controlingMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPartsBin commentStamp: 'pt 7/16/2009 16:52' prior: 0!
A parts bin, that allows Phidget-Morphs to behave like the objects tool to create new Ports.
It overwrites some methods of the parts bin to allow that the created Morph knows its creator (the Phidget holding this bin).
This PartsBin is used by PhdETPortBasedPhidget and its subclasses.!

!PhdETPartsBin class methodsFor: 'thumbnail cache' stamp: 'pt 5/7/2009 13:17'!
thumbnailForQuad: aQuint color: aColor phidget: aPhidget
	"Answer a thumbnail for a morph obtaining as per the quintuplet provided, creating the thumbnail if necessary.  If it is created afresh, it will also be cached at this time"

	| aThumbnail aSymbol formToThumbnail labeledItem |
	aSymbol := aQuint third.
	Thumbnails at: aSymbol ifPresent: [ :thumb | ^thumb ].
	formToThumbnail := aQuint at: 5 ifAbsent: [].
	formToThumbnail ifNil: [
		labeledItem := (Smalltalk at: aQuint first) perform: aQuint second with: aPhidget.
		formToThumbnail := labeledItem imageForm: 32 backgroundColor: aColor forRectangle: labeledItem fullBounds.
		formToThumbnail replaceColor: aColor withColor: Color transparent.
	].

	aThumbnail := Thumbnail new makeThumbnailFromForm: formToThumbnail.
	self cacheThumbnail: aThumbnail forSymbol: aSymbol.
	^ aThumbnail

"PartsBin initialize"! !

!PhdETPartsBin methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:12'!
controlingMorph

	^ controlingMorph! !

!PhdETPartsBin methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:12'!
controlingMorph: aMorph

	controlingMorph := aMorph.! !

!PhdETPartsBin methodsFor: 'initialization' stamp: 'pt 7/24/2009 15:15'!
listDirection: aListDirection quadList: quadList
	"Initialize the receiver to run horizontally or vertically, obtaining its elements from the list of tuples of the form:
		(<receiver> <selector> <label> <balloonHelp>)
	Original Method in Parts bin - only 1 line changed."

	| aButton aClass |
	self layoutPolicy: TableLayout new.
	self listDirection: aListDirection.
	self wrapCentering: #center.
	self layoutInset: 2.
	self cellPositioning: #bottomCenter.

	aListDirection == #leftToRight
		ifTrue:
			[self vResizing: #rigid.
			self hResizing: #spaceFill.
			self wrapDirection: #topToBottom]
		ifFalse:
			[self hResizing: #rigid.
			self vResizing: #spaceFill.
			self wrapDirection: #leftToRight].
	quadList do:
		[:tuple |
			aClass := Smalltalk at: tuple first.
			aButton := IconicButton new initializeWithThumbnail: (self class thumbnailForQuad: tuple color: self color phidget: self phidget) withLabel: tuple third andColor: self color andSend: tuple second to: aClass with: self phidget.
			(tuple size > 3 and: [tuple fourth isEmptyOrNil not]) ifTrue:
				[aButton setBalloonText: tuple fourth].
 			self addMorphBack: aButton]! !

!PhdETPartsBin methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:15'!
phidget

	^ controlingMorph! !

RectangleMorph subclass: #PhdETBarMorph
	instanceVariableNames: 'min max value statusMorph lineMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETBarMorph commentStamp: 'pt 7/15/2009 18:59' prior: 0!
A simple BarMorph.
It shows a value within a given interval.
The bar that shows the value "grows" from my center.
Set the interval with #maxValue: and #minValue:
Set the value with #value:

Change the bar's color with #barColor:
Change the color that is shown behind the bar with #backColor:'

This Morph is used e.g. in PhdETMotorControl!

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:53'!
backColor

	^ self color! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:53'!
backColor: aColor

	self color: aColor.! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
barColor

	^ statusMorph color! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
barColor: aColor

	statusMorph color: aColor.! !

!PhdETBarMorph methodsFor: 'private' stamp: 'pt 7/16/2009 14:12'!
calcStatusMorphDirection

	| interval |
	interval := max - min asFloat.
	
	^ interval == 0
		ifTrue: [ 0 ]
		ifFalse: [ value asFloat - min / interval - 0.5 ].! !

!PhdETBarMorph methodsFor: 'private' stamp: 'pt 7/16/2009 14:26'!
calcStatusMorphPosition: direction forWidth: newWidth
	"Calculates the new position of the statusMorph. Used by #updateStatus."
	
	| middle |
	middle := self center x.
	
	^ direction < 0
		ifTrue: [ (middle - newWidth @ self position y) + (1@1) ]
		ifFalse: [ (middle @ self position y) + (-1@1) ].! !

!PhdETBarMorph methodsFor: 'private' stamp: 'pt 7/16/2009 14:26'!
calcStatusMorphWidth: direction
	"Calculates the new width of the statusMorph. Used by #updateStatus."
	
	^ (self width asFloat * (direction abs)) rounded! !

!PhdETBarMorph methodsFor: 'initialization' stamp: 'pt 7/16/2009 16:02'!
createAndAddMiddleLine

	lineMorph := PolygonMorph
		createLineFrom: statusMorph topCenter
		to: statusMorph bottomCenter
		color: Color black
		width: 2.
	self addMorph: lineMorph.! !

!PhdETBarMorph methodsFor: 'initialization' stamp: 'pt 7/15/2009 18:53'!
createAndAddStatusMorph

	statusMorph := BorderedMorph new
		borderWidth: 1;
		color: Color green muchLighter;
		yourself.
	self
		addMorph: statusMorph;
		updateStatus.! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/16/2009 14:39'!
height: newHeight

	super height: newHeight.
	self updateStatus.! !

!PhdETBarMorph methodsFor: 'initialization' stamp: 'pt 7/15/2009 22:09'!
initialize

	super initialize.
	min := 0.
	max := 1000.
	value := 0.
	self
		color: Color darkGray;
		createAndAddStatusMorph;
		createAndAddMiddleLine.! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
maxValue

	^ max! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
maxValue: aNumber

	max := aNumber.
	self updateStatus.! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
minValue

	^ min! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
minValue: aNumber

	min := aNumber.
	self updateStatus.! !

!PhdETBarMorph methodsFor: 'private' stamp: 'pt 7/16/2009 14:37'!
updateMiddleLine

	lineMorph ifNotNil: [
		lineMorph setVertices: { 
			self topCenter + (0@1).
			self bottomCenter - (0@1) } ].! !

!PhdETBarMorph methodsFor: 'private' stamp: 'pt 7/16/2009 15:54'!
updateStatus
	"Update my statusMorph."
	
	| expansion newPosition newWidth |
	expansion := self calcStatusMorphDirection.
	"expansion is a float between -0.5 and 0.5, representing direction and length of the new status morph bar."
	
	newWidth := self calcStatusMorphWidth: expansion.
	newPosition := self calcStatusMorphPosition: expansion forWidth: newWidth.
	
	statusMorph
		position: newPosition;
		height: self height - 2;
		width: newWidth.
		
	self updateMiddleLine.
	! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
value

	^ value! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 18:54'!
value: aNumber

	value := aNumber.
	self updateStatus.! !

!PhdETBarMorph methodsFor: 'accessing' stamp: 'pt 7/16/2009 14:36'!
width: newWidth

	super width: newWidth.
	self updateStatus.! !

PhdETBarMorph subclass: #PhdETPositiveBarMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPositiveBarMorph commentStamp: 'pt 7/15/2009 18:59' prior: 0!
A simple BarMorph.
It shows a value within a given interval.
The bar that shows the value "grows" from my left border.
Set the interval with #maxValue: and #minValue:
Set the value with #value:

Change the bar's color with #barColor:
Change the color that is shown behind the bar with #backColor:'

This Morph is used e.g. in PhdETIfKitSensorPort!

!PhdETPositiveBarMorph methodsFor: 'initialization' stamp: 'pt 7/24/2009 13:08'!
createAndAddMiddleLine
	"I need no line, so I just return self here."
	
	^ self! !

!PhdETPositiveBarMorph methodsFor: 'private' stamp: 'pt 7/24/2009 13:14'!
updateStatus
	"repositioning (and resizing) my status morph"
	
	| newWidth |
	max = min
		ifTrue: [ newWidth := 0 ]
		ifFalse: [ newWidth := self width asFloat * (value asFloat - min) / (max - min asFloat) - 2].
	newWidth < 0 ifTrue: [ newWidth := 0 ].
	statusMorph
		position: self position + (1@1);
		height: self height - 2;
		width: newWidth.
	! !

TransformationMorph subclass: #PhdETWheelMorph
	instanceVariableNames: 'speed minSpeed maxSpeed rotationAngle rotationTime rotationStep'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETWheelMorph commentStamp: 'pt 7/24/2009 12:43' prior: 0!
A PhdETWheelMorph is a Morph representing a wheel. It is able to spin with a given speed (therefore it uses the step Method).

Instance Variables
	maxSpeed:		a Float
	minSpeed:		a Float
	rotationAngle:	a Float
	rotationStep:	a Float
	rotationTime:	an Integer
	speed:			a Float

maxSpeed
	- A Float indicating the maximum speed.

minSpeed
	- A Float indicating the minimum speed.

rotationAngle
	- My current angle (in radians).

rotationStep
	- The angle (in radians) I turn every step.

rotationTime
	- An Integer: The wheel turns every <rotationTime> milliseconds.

speed
	- A Float in the interval [minSpeed, maxSpeed] indicating the current speed.
!

!PhdETWheelMorph class methodsFor: 'as yet unclassified' stamp: 'lk 7/24/2009 14:42'!
numberOfSpokes

	^ 11! !

!PhdETWheelMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:06'!
addSpokesToWheel: aCircle
	"add a number of spokes to the currently still empty wheel.
	start point is the center of the circle, the end point is calculated for every spoke."
	
	| radius line start end angle step |
	self class numberOfSpokes == 0 ifTrue: [ ^ self ].
	
	radius := aCircle width asFloat / 2.0.
	angle := 0.0.
	step := Float pi * 2 / self class numberOfSpokes.
	start := aCircle center.
	
	[ angle <= (Float pi * 2.0) ] whileTrue: [
		end := start - ( (angle cos * radius) @ (angle sin * radius) ).
		line := PolygonMorph
			createLineFrom: start
			to: end
			color: Color black
			width: 1.
		aCircle addMorph: line.
		angle := angle + step ].
	! !

!PhdETWheelMorph methodsFor: 'accessing' stamp: 'lk 7/24/2009 14:32'!
calcRotationParameters
	"calculate the new step size for rotation."
	
	| normalizedSpeed |
	normalizedSpeed := speed / (maxSpeed - minSpeed). "-> 0.0 <= normalizedSpeed <= 1.0"
	rotationStep := normalizedSpeed asFloat / 3.! !

!PhdETWheelMorph methodsFor: 'initialization' stamp: 'pt 7/15/2009 11:49'!
createWheel
	"create and return a CircleMorph that looks like a wheel."
	
	| circle diameter |
	circle := CircleMorph new.
	diameter := 80.
	circle
		extent: diameter@diameter;
		color: (Color white);
		borderWidth: 3.
	self addSpokesToWheel: circle.
	^ circle! !

!PhdETWheelMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 14:29'!
initialize

	super initialize.
	
	speed := 0.0.
	minSpeed := 0.0.
	maxSpeed := 1000.0.
	rotationTime := 100.
	rotationAngle := 0.0.
	
	self
		calcRotationParameters;
		asFlexOf: self createWheel.! !

!PhdETWheelMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 11:56'!
maxSpeed

	^ maxSpeed! !

!PhdETWheelMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 11:57'!
maxSpeed: aFloat

	maxSpeed := aFloat.
	self calcRotationParameters.! !

!PhdETWheelMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 11:56'!
minSpeed

	^ minSpeed! !

!PhdETWheelMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 11:56'!
minSpeed: aFloat

	minSpeed := aFloat.
	self calcRotationParameters.! !

!PhdETWheelMorph methodsFor: 'animation' stamp: 'lk 7/24/2009 14:30'!
rotate
	"This method is called from step. Increment the current rotation angle, normalize it and set the new angle."

	rotationAngle := rotationAngle + rotationStep.
	rotationAngle > (Float pi * 2) ifTrue: [ rotationAngle := rotationAngle - (Float pi * 2) ].
	self angle: rotationAngle.! !

!PhdETWheelMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 10:38'!
speed

	^ speed! !

!PhdETWheelMorph methodsFor: 'accessing' stamp: 'pt 7/15/2009 11:57'!
speed: aFloat

	speed := aFloat.
	self calcRotationParameters.! !

!PhdETWheelMorph methodsFor: 'animation' stamp: 'pt 7/15/2009 09:56'!
step
	
	self rotate.! !

!PhdETWheelMorph methodsFor: 'animation' stamp: 'pt 7/15/2009 11:53'!
stepTime

	^ rotationTime! !

MixedCurveMorph subclass: #PhdETSegmentOfCircle
	instanceVariableNames: 'center radius angleA angleB'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETSegmentOfCircle commentStamp: 'pt 7/24/2009 13:02' prior: 0!
A PhdETSegmentOfCircle is a Morph indicating a shadow, showing the area which is not reachable for the servo.

Instance Variables
	angleA:		a Float
	angleB:		a Float
	center:		a Point
	radius:		an Integer

angleA
	- An angle (in degree) indicating the beginning of the shadow.

angleB
	- An angle (in degree) indicating the end of the shadow.

center
	- A Point indicating the center of the segment of the circle

radius
	- A Float indicating the radius of the segment of the circle.!

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 6/3/2009 12:22'!
angleA

	^ angleA! !

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 7/24/2009 12:57'!
angleA: anAngle
	"must be in degrees and between 0 and 360"
	
	( 0 <= anAngle and: [ anAngle <= 360 ] ) ifTrue: [
		angleA := anAngle.
		self updateShape ].! !

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 6/3/2009 12:22'!
angleB

	^ angleB! !

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 7/24/2009 12:57'!
angleB: anAngle
	"must be in degrees and between 0 and 360"
	
	( 0 <= anAngle and: [ anAngle <= 360 ] ) ifTrue: [
		angleB := anAngle.
		self updateShape ].! !

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 6/3/2009 12:28'!
circleCenter

	^ center! !

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 6/3/2009 12:28'!
circleCenter: aPoint

	center := aPoint.
	self updateShape.! !

!PhdETSegmentOfCircle methodsFor: 'initialization' stamp: 'lk 7/24/2009 14:20'!
initialize

	super initialize.
	
	center := 0@0.
	angleA := 0.
	angleB  := 0.
	radius := 1.
	slopeClamps := #(0 0 nil 0).
	
	self
		color: (Color black alpha: 0.5);
		borderColor: Color transparent;
		updateShape.! !

!PhdETSegmentOfCircle methodsFor: 'converting' stamp: 'pt 7/24/2009 12:00'!
pointFromAngle: angle
	"Calculates the point of the circle belonging to an angle.
	angle must be in degrees (0<=angle<=360)"
	
	| x y |
	x := ( self servoRadians: angle ) cos * radius.
	y := ( self servoRadians: angle ) sin * radius.
	^ x@y! !

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 6/3/2009 12:22'!
radius

	^ radius! !

!PhdETSegmentOfCircle methodsFor: 'accessing' stamp: 'pt 6/3/2009 12:26'!
radius: aNumber

	radius := aNumber.
	self updateShape.! !

!PhdETSegmentOfCircle methodsFor: 'converting' stamp: 'pt 7/24/2009 12:58'!
servoRadians: aFloat
	"Converts the float (an angle in degrees) to radians. By the way it turns the 0 position to a 270 position (looks better in the resulting Morph ;))"
	
	| f |
	f := aFloat -90.0.
	(f<0) ifTrue: [ f := f + 360.0 ].
	^ f degreesToRadians! !

!PhdETSegmentOfCircle methodsFor: 'updating' stamp: 'lk 7/24/2009 14:23'!
updateShape

	self setVertices: {
		center.
		center + (self pointFromAngle: angleA).
		center + (self pointFromAngle: angleA + angleB / 2).		"center of circle segment line"
		center + (self pointFromAngle: angleB) }.! !

Object subclass: #PhdETInitialise
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETInitialise class methodsFor: 'Thumbnail creation' stamp: 'lk 7/24/2009 18:51'!
createThumbnails

	PhdETPhidget allSubclasses do: [ :class | | quint color description |
		class hasThumbnail ifTrue: [
			description := class descriptionForPartsBin.
			quint := {
				class asString asSymbol.
				#createThumbnail. 
				description formalName.
				description documentation }.
			color := Color r: 1.0 g: 0.911 b: 0.984.
			PartsBin thumbnailForQuad: quint color: color ].
		].! !

CircleMorph subclass: #PhdETGyroMorph
	instanceVariableNames: 'angleLine orientationCircle x y z'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETGyroMorph commentStamp: 'pt 7/16/2009 16:45' prior: 0!
A Morph used to show the current status of the PhdETAccelerometer.!

!PhdETGyroMorph methodsFor: 'initialization' stamp: 'pt 7/16/2009 16:02'!
createAndAddAngleLine
	"creates a line (PolygonMorph) as a Submorph to me."
	
	angleLine := PolygonMorph 
		createLineFrom: self center
		to: self center
		color: Color black
		width: 3.
	self
		addMorph: angleLine;
		updateAngleLine.! !

!PhdETGyroMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 14:15'!
createAndAddOrientationCircle
	
	orientationCircle := CircleMorph new
		color: Color transparent;
		borderColor: Color green darker;
		borderWidth: 2;
		yourself.
	self
		addMorph: orientationCircle;
		updateOrientationCircle.! !

!PhdETGyroMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 14:15'!
initialize

	super initialize.
	
	self 
		color: Color white;
		x: 0.0;
		y: 0.0;
		z: 0.0;
		createAndAddAngleLine;
		createAndAddOrientationCircle.! !

!PhdETGyroMorph methodsFor: 'private' stamp: 'pt 7/2/2009 13:23'!
update
	"update my appereance"
	
	self
		updateAngleLine;
		updateOrientationCircle.! !

!PhdETGyroMorph methodsFor: 'private' stamp: 'pt 7/2/2009 13:20'!
updateAngleLine

	| radius newPoint |
	radius := self width / 2.0.
	
	newPoint := (x sin * radius * -1) @ (y sin * radius * -1).
	angleLine setVertices: { self center . self center + newPoint }.! !

!PhdETGyroMorph methodsFor: 'private' stamp: 'pt 7/2/2009 13:53'!
updateOrientationCircle

	self
		updateOrientationCircleColor;
		updateOrientationCircleRadius.
	! !

!PhdETGyroMorph methodsFor: 'private' stamp: 'pt 7/2/2009 13:52'!
updateOrientationCircleColor

	z < 0
		ifTrue:  [ orientationCircle borderColor: Color red darker ]
		ifFalse: [ orientationCircle borderColor: Color green darker ].
	! !

!PhdETGyroMorph methodsFor: 'private' stamp: 'lk 7/24/2009 14:12'!
updateOrientationCircleRadius

	| newDiameter |
	
	newDiameter := ((z abs sin * self width) + 2).
	
	orientationCircle
		extent: newDiameter @ newDiameter;
		center: self center.! !

!PhdETGyroMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:09'!
x

	^ x! !

!PhdETGyroMorph methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:03'!
x: aFloat

	x := aFloat.! !

!PhdETGyroMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:09'!
y

	^ y! !

!PhdETGyroMorph methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:03'!
y: aFloat

	y := aFloat.! !

!PhdETGyroMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:09'!
z

	^ z! !

!PhdETGyroMorph methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:04'!
z: aFloat

	z := aFloat.! !

CircleMorph subclass: #PhdETOnOffStatusMorph
	instanceVariableNames: 'status'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETOnOffStatusMorph commentStamp: 'pt 7/16/2009 16:46' prior: 0!
A Morph showing wether a Boolean is true or false using the lit (or not lit) lamp metaphor.
It is used eg. in PhdETInputPort and PhdETOutputPort.!

!PhdETOnOffStatusMorph methodsFor: 'initialization' stamp: 'pt 7/24/2009 15:10'!
initialize

	super initialize.
	self borderWidth: 2.
	self off.! !

!PhdETOnOffStatusMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:10'!
off

	status := false.
	self borderColor: Color black.
	self color: Color lightGray.! !

!PhdETOnOffStatusMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:10'!
on

	status := true.
	self borderColor: Color yellow muchDarker.
	self color: Color yellow.! !

!PhdETOnOffStatusMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:10'!
setStatus: aBoolean

	aBoolean
		ifTrue: [ self on ]
		ifFalse: [ self off ].! !

CircleMorph subclass: #PhdETServoPositionMorph
	instanceVariableNames: 'min max current minMorph maxMorph currentMorph lineExtension shadowMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETServoPositionMorph commentStamp: 'pt 7/24/2009 12:51' prior: 0!
A PhdETServoPositionMorph is a morph that visualizes the properties of a servo motor.
Properties are the maximum and minimum possible position and the current position of the servo.

Instance Variables
	current:		a Float
	currentMorph:	a PolygonMorph
	lineExtension:	an Integer
	max:			a Float
	maxMorph:		a PolygonMorph
	min:			a Float
	minMorph:		a PolygonMorph
	shadowMorph:	a PhdETSegmentOfCircle

current
	- The angle in degress presenting the current position of my servo.

currentMorph
	- The Morph representing the pointer to visualize the current position of the servo.

lineExtension
	- The Number of pixel the min/max lines are visible (=extend) beyond the circle.

max
	- The maximal able position of a servo to set to.

maxMorph
	- The Morph representing a little pointer to visualize the maximal able position of the servo.

min
	- The minimal able position of a servo to set to.

minMorph
	- The Morph representing a little pointer to visualize the minimal able position of the servo.

shadowMorph
	- A Morph indicating a shadow, showing the area which is not reachable for the servo.
!

!PhdETServoPositionMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:13'!
createAndAddCurrentMorph
	"creates a line (PolygonMorph) as a Submorph to me."
	"I represent a pointer to visualize the current position of my servo."
	
	currentMorph := PolygonMorph 
		createLineFrom: self position
		to: self position + (1 @ 1)
		color: Color black
		width: 3.
	self addMorph: currentMorph.! !

!PhdETServoPositionMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:13'!
createAndAddMaxMorph
	"The Morph representing a little pointer to visualize the maximal able position of the servo."
	
	maxMorph := PolygonMorph 
		createLineFrom: self position
		to: self position + (1 @ 1)
		color: Color red
		width: 2.
	self addMorph: maxMorph.! !

!PhdETServoPositionMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:14'!
createAndAddMinMorph
	"The Morph representing a little pointer to visualize the minimal able position of the servo."

	minMorph := PolygonMorph 
		createLineFrom: self position
		to: self position + (1 @ 1)
		color: (Color r: 0 g: 0.3 b: 0)
		width: 2.
	self addMorph: minMorph.! !

!PhdETServoPositionMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:14'!
createAndAddShadowMorph
	"The Morph to visualize the area which the currentMorph can't reach."

	shadowMorph := PhdETSegmentOfCircle new
		circleCenter: self center;
		radius: self width / 2.
	self addMorph: shadowMorph.! !

!PhdETServoPositionMorph methodsFor: 'initialization' stamp: 'pt 7/24/2009 11:42'!
createAndAddSubmorphs

	self
		createAndAddMinMorph;
		createAndAddMaxMorph;
		createAndAddCurrentMorph;
		createAndAddShadowMorph.! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'pt 6/2/2009 16:01'!
current

	^ current! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 11:33'!
current: aFloat
	"The angle in degrees presenting the current position of my servo."

	( ( 0 <= aFloat ) and: [ aFloat <= 360 ] )  ifTrue: [
		current := aFloat.
		self updateCurrentMorph ].! !

!PhdETServoPositionMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:10'!
initialize

	super initialize.
	
	lineExtension := 4.
	min := 0.
	max := 180.
	current := 90.
	
	self
		color: Color white;
		createAndAddSubmorphs;
		updateSubmorphs.! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 11:55'!
lineExtension

	^ lineExtension! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'pt 6/3/2009 01:24'!
lineExtension: aNumber
	"The number of pixel the min/max lines are visible (=extend) beyond the circle."

	lineExtension := aNumber.! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'pt 6/2/2009 16:01'!
max

	^ max! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:09'!
max: aFloat
	"The maximal possible position of a servo to set to"

	( ( 0 <= aFloat ) and: [ aFloat <= 360 ] )  ifTrue: [
		max := aFloat.
		self updateMaxMorph ].! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'pt 6/2/2009 16:01'!
min

	^ min! !

!PhdETServoPositionMorph methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:09'!
min: aFloat
	"The minimal possible position of a servo to set to"

	( ( 0 <= aFloat ) and: [ aFloat <= 360 ] )  ifTrue: [
		min := aFloat.
		self updateMinMorph ].! !

!PhdETServoPositionMorph methodsFor: 'converting' stamp: 'pt 7/24/2009 12:05'!
servoRadians: aFloat
	"Converts the float (an angle in degrees) to radians. By the way it turns the 0 position to a 270 position (looks better in the resulting Morph ;))"

	| f |
	f := aFloat -90.0.
	(f<0) ifTrue: [ f := f + 360.0 ].
	^ f degreesToRadians! !

!PhdETServoPositionMorph methodsFor: 'updating' stamp: 'lk 7/24/2009 15:16'!
updateCurrentMorph

	| position radius |
	radius := self width / 2.0.
	position := ( (self servoRadians: self current) cos * radius )
		@ ( (self servoRadians: self current) sin * radius ).
	currentMorph setVertices: {
		self center.
		self center + position }.! !

!PhdETServoPositionMorph methodsFor: 'updating' stamp: 'lk 7/24/2009 15:18'!
updateMaxMorph

	| point1 point2 radius x y |
	radius := self width / 2.0.
	x := (self servoRadians: self max) cos.
	y := (self servoRadians: self max) sin.
	point1 := ( x * ( radius - self lineExtension ) ) @ ( y * ( radius - self lineExtension ) ).
	point2 := ( x * ( radius + self lineExtension ) ) @ ( y * ( radius + self lineExtension ) ).
	maxMorph setVertices: {
		self center + point1.
		self center + point2 }.
	
	self updateShadowMorph.! !

!PhdETServoPositionMorph methodsFor: 'updating' stamp: 'lk 7/24/2009 15:20'!
updateMinMorph

	| point1 point2 radius x y |
	radius := self width / 2.0.
	x := (self servoRadians: self min) cos.
	y := (self servoRadians: self min) sin.
	point1 := ( x * ( radius - self lineExtension ) ) @ ( y * ( radius - self lineExtension ) ).
	point2 := ( x * ( radius + self lineExtension ) ) @ ( y * ( radius + self lineExtension ) ).
	minMorph setVertices: {
		self center + point1.
		self center + point2 }.
	
	self updateShadowMorph.! !

!PhdETServoPositionMorph methodsFor: 'updating' stamp: 'pt 6/3/2009 16:28'!
updateShadowMorph

	shadowMorph
		circleCenter: self center;
		radius: self width / 2;
		angleA: max;
		angleB: min.! !

!PhdETServoPositionMorph methodsFor: 'updating' stamp: 'pt 6/3/2009 16:27'!
updateSubmorphs

	self
		updateMinMorph;
		updateMaxMorph;
		updateCurrentMorph;
		updateShadowMorph.! !

BorderedMorph subclass: #PhdETPhidget
	instanceVariableNames: 'phidHandle labelMorph thumbnailCreation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPhidget commentStamp: 'pt 7/23/2009 17:37' prior: 0!
This is an abstract class defining some messages every Phidget-Morph needs.
E.g. it creates the Etoys-category 'Phidget' and adds 'Attached' and 'Label'.

Instance Variables
	phidHandle: a PhdCrPhidget
	lableMorph: a StringMorph
	
phidHandle:
	- A PhdCrPhidget used to get the values and information of the Phidget I want to display.
	
lableMorph:
	- A StringMorph showing my label.!

PhdETPhidget subclass: #PhdETAccelerometer
	instanceVariableNames: 'gyroMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETAccelerometer commentStamp: 'pt 7/23/2009 17:38' prior: 0!
I am a representation of a Phidget called 'Accelerometer' in Etoys.
You can drag me out of the objects tool in the category Phidgets.

Instance Variables
	gyroMorph: A PhdETGyroMorph

gyroMorph:
	- A PhdETGyroMorph that shows my current position depending on the x-,y-,z-axis.!

!PhdETAccelerometer class methodsFor: 'Etoys-Support' stamp: 'pt 7/14/2009 15:30'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		#(
			#Phidget
			#(
				#(
					#slot
					#RotationAroundX
					'Rotation around the x-axis. (-90.0 - 90.0)'
					#Float
					#readOnly
					#Player
					#getAcclRotationAroundX
					#unused
					#unused
				)
				#(
					#slot
					#RotationAroundY
					'Rotation around the y-axis. (-90.0 - 90.0)'
					#Float
					#readOnly
					#Player
					#getAcclRotationAroundY
					#unused
					#unused
				)
				#(
					#slot
					#RotationAroundZ
					'Rotation around the z-axis. (-90.0 - 90.0)'
					#Float
					#readOnly
					#Player
					#getAcclRotationAroundZ
					#unused
					#unused
				)
				#(
					#slot
					#RotationAroundXNumber
					'Rotation around the x-axis mapped to a Number between 0 and 1000.'
					#Number
					#readOnly
					#Player
					#getAcclRotationAroundXNumber
					#unused
					#unused
				)
				#(
					#slot
					#RotationAroundYNumber
					'Rotation around the y-axis mapped to a Number between 0 and 1000.'
					#Number
					#readOnly
					#Player
					#getAcclRotationAroundYNumber
					#unused
					#unused
				)
				#(
					#slot
					#RotationAroundZNumber
					'Rotation around the z-axis mapped to a Number between 0 and 1000.'
					#Number
					#readOnly
					#Player
					#getAcclRotationAroundZNumber
					#unused
					#unused
				)
			)
		)
	)! !

!PhdETAccelerometer class methodsFor: 'parts bin' stamp: 'pt 6/24/2009 09:38'!
descriptionForPartsBin
    ^ self partName:    'Accelerometer'
        categories:     #('Phidgets')
        documentation:  'This is a three axis accelerometer that measures 3 gravities change per axis. It measures both dynamic acceleration (vibration) and static acceleration (gravity or tilt).'! !

!PhdETAccelerometer class methodsFor: 'Etoys-Support' stamp: 'lk 7/24/2009 18:48'!
hasThumbnail

	^ true! !

!PhdETAccelerometer methodsFor: 'converting' stamp: 'pt 6/24/2009 10:06'!
angleToNumber: anAngle
	"Converts an angle (-90.0 - 90.0) to an Integer (0 - 1000)."
	
	^ anAngle asFloat + 90.0 / 180.0 * 1000.0! !

!PhdETAccelerometer methodsFor: 'events' stamp: 'lk 7/24/2009 16:02'!
attach
	"Use a higher change trigger by default, because the view would flicker to much."

	phidHandle changeTrigger: 0.1.
	self updateGyroMorph.! !

!PhdETAccelerometer methodsFor: 'initialization' stamp: 'lk 7/24/2009 16:03'!
createAndAddSubmorphs

	super createAndAddSubmorphs.
	
	gyroMorph := PhdETGyroMorph new
		extent: 70@70;
		update;
		yourself.
	self addMorph: gyroMorph.! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:17'!
getAcclRotationAroundX

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 2) angleDegrees! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 6/24/2009 10:26'!
getAcclRotationAroundXNumber

	^ self angleToNumber: self getAcclRotationAroundX! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:16'!
getAcclRotationAroundY

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 3) angleDegrees! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 6/24/2009 10:26'!
getAcclRotationAroundYNumber

	^ self angleToNumber: self getAcclRotationAroundY! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:16'!
getAcclRotationAroundZ

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 1) angleDegrees! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 6/24/2009 10:26'!
getAcclRotationAroundZNumber

	^ self angleToNumber: self getAcclRotationAroundZ! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:19'!
getDegreesX

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 1) angleDegrees! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:19'!
getDegreesY

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 2) angleDegrees! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:19'!
getDegreesZ

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 3) angleDegrees! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:18'!
getRadiansX

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 1) angleRadians! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:18'!
getRadiansY

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 2) angleRadians! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/2/2009 12:18'!
getRadiansZ

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle axes at: 3) angleRadians! !

!PhdETAccelerometer methodsFor: 'initialization' stamp: 'lk 7/24/2009 16:03'!
initialize

	self 
		initPhidget: PhdCrAccelerometer new
		withLabel: 'Accelerometer';
		width: 150;
		height: 110;
		initializeGyroMorph.
		
	phidHandle
		on: #Attach do: [ self attach ];
		on: #Detach do: [ self updateGyroMorph ];
		on: #AccelerationChange do: [ self updateGyroMorph ].! !

!PhdETAccelerometer methodsFor: 'initialization' stamp: 'pt 7/2/2009 13:34'!
initializeGyroMorph
		
	self positionGyroMorph.! !

!PhdETAccelerometer methodsFor: 'accessing' stamp: 'pt 7/14/2009 15:19'!
positionGyroMorph

	gyroMorph center: self center + (0 @ 10)! !

!PhdETAccelerometer methodsFor: 'events' stamp: 'pt 7/2/2009 12:20'!
updateGyroMorph

	gyroMorph
		x: self getRadiansX;
		y: self getRadiansY;
		z: self getRadiansZ;
		update.! !

!PhdETPhidget class methodsFor: 'Etoys-Support' stamp: 'pt 5/28/2009 14:26'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		(Phidget (
			(slot Label 'The label of this Phidget.' String readWrite Player getLabel Player setLabel:)
			(slot Attached 'This is wether the Phidget is attached to the USB port or not.' Boolean readOnly Player getAttached unused unused)
		))
	)

! !

!PhdETPhidget class methodsFor: 'Etoys-Support' stamp: 'lk 7/24/2009 18:35'!
createThumbnail
	"Answer an instance capable of standing by its self as a usable morph - without opening a real phidget handle."

	^ self basicNew initializeForThumbnail! !

!PhdETPhidget class methodsFor: 'Etoys-Support' stamp: 'lk 7/24/2009 18:48'!
hasThumbnail

	^ false! !

!PhdETPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 14:38'!
adaptSize
	"Adjusts submorphs to fit perfectly - even if I was resized."
	
	self positionLabel.! !

!PhdETPhidget methodsFor: 'private' stamp: 'pt 7/24/2009 15:19'!
changed

	super changed.
	self adaptSize.! !

!PhdETPhidget methodsFor: 'initialization' stamp: 'pt 7/24/2009 15:52'!
createAndAddSubmorphs
	"Create and add label - subclasses may overwrite this method to createAndAdd more Morphs (like status morphs)."
	
	labelMorph := StringMorph new font: (TextStyle default fontAt: 2) emphasis: 1.
	self addMorph: labelMorph.! !

!PhdETPhidget methodsFor: 'submorphs-add/remove' stamp: 'pt 7/24/2009 15:20'!
delete

	phidHandle close.
	super delete.! !

!PhdETPhidget methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:20'!
getAttached

	^ phidHandle isAttached! !

!PhdETPhidget methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:20'!
getLabel

	^ labelMorph contents! !

!PhdETPhidget methodsFor: 'initialization' stamp: 'pt 7/24/2009 19:23'!
initPhidget: aPhidHandle withLabel: aLabel
	"Open the given Phidget, create a new PhidgetMorph including its label.
	To add other submorphs than the label, overwrite createAndAddSubmorphs in the
	corresponding subclass of PhdETPhidget."
	
	super initialize.
	phidHandle := aPhidHandle.
	self createAndAddSubmorphs.
	
	"Set standard size and color."
	self
		setLabel: aLabel;
		width: 290;
		height: 75;
		color: (Color r: 0.4 g: 0.7 b: 0.4);
		useRoundedCorners.
	
	"open the phidget, so that it's ready to be used"
	thumbnailCreation ifFalse: [ phidHandle openAny ].! !

!PhdETPhidget methodsFor: 'initialization' stamp: 'lk 7/24/2009 18:56'!
initializeForThumbnail

	thumbnailCreation := true.
	self initialize.! !

!PhdETPhidget methodsFor: 'initialization' stamp: 'lk 7/24/2009 18:39'!
initializeToStandAlone

	thumbnailCreation := false.
	self initialize.! !

!PhdETPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 14:31'!
positionLabel

	labelMorph position: self center - ( labelMorph width / 2 @ ( self height / 2 - 4 ) ).! !

!PhdETPhidget methodsFor: 'accessing' stamp: 'pt 7/24/2009 15:24'!
setLabel: anObject
	"Set my label (and Etoys name) and repositions my labelMorph so that it is still centered. I also update my Etoys name here."

	labelMorph contents: anObject asString.
	(self player) ifNotNil: [
		self player setName: labelMorph contents ].
	self positionLabel.
! !

PhdETPhidget subclass: #PhdETPortBasedPhidget
	instanceVariableNames: 'ports bin'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPortBasedPhidget commentStamp: 'pt 7/23/2009 17:51' prior: 0!
A PhdETPortBasedPhidget is an abstract class that enables Phidget Morphs to have (multiple) Ports.
Therefore I use my bin.

Instance Variables
	bin:		a PhdETPartsBin
	ports:	an OrderedCollection

bin
	- A parts bin that works much the same like the object tools PartsBin. You can drag Ports out of it.

ports
	- An OrderedCollection holding all the port that were dragged out of me.
!

PhdETPortBasedPhidget subclass: #PhdETInterfaceKit
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETInterfaceKit commentStamp: 'pt 7/23/2009 17:52' prior: 0!
I am a representation of a Phidget called 'Interface Kit' in Etoys.
You can drag me out of the objects tool in the category Phidgets.
!

!PhdETInterfaceKit class methodsFor: 'parts bin' stamp: 'pt 5/3/2009 19:18'!
descriptionForPartsBin
    ^ self partName:    'InterfaceKit'
        categories:     #('Phidgets')
        documentation:  'An Interface Kit'! !

!PhdETInterfaceKit class methodsFor: 'Etoys-Support' stamp: 'lk 7/24/2009 18:50'!
hasThumbnail

	^ true! !

!PhdETInterfaceKit methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:55'!
collectPortDescriptorQuads
	"Lists the Ports I want to show."

	| quads |
	quads := OrderedCollection new.
	PhdETInputPort addPortDescriptorQuadsTo: quads.
	PhdETOutputPort addPortDescriptorQuadsTo: quads.
	PhdETSensorPort addPortDescriptorQuadsTo: quads.
	^ quads! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 7/1/2009 14:59'!
getInput: index

	(phidHandle isAttached and: [phidHandle inputs indexIsInRange: index]) ifTrue: [
		^ (phidHandle inputs at: index) value ].

	^ false! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 7/1/2009 14:59'!
getOutput: index

	(phidHandle isAttached and: [phidHandle outputs indexIsInRange: index]) ifTrue: [
		^ (phidHandle outputs at: index) value ].

	^ false! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 7/1/2009 15:00'!
getSensor: index

	(phidHandle isAttached and: [phidHandle sensors indexIsInRange: index]) ifTrue: [
		^ (phidHandle sensors at: index) value ].

	^ 0! !

!PhdETInterfaceKit methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:56'!
initialize

	self initPhidget: PhdCrInterfaceKit new withLabel: 'Interface Kit'.
	
	phidHandle
		on: #InputChange do: [ self inputChange ];
		on: #OutputChange do: [ self outputChange ];
		on: #SensorChange do: [ self sensorChange ].! !

!PhdETInterfaceKit methodsFor: 'events' stamp: 'lk 7/24/2009 15:56'!
inputChange
	"This method is called if an inputValue has changed.
	We update our visible inputPorts here."
	
	self ports do: [ :port | port update: #inputPort ].! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 7/16/2009 16:11'!
inputPortAvailable: portNumber

	^ phidHandle isAttached and: [ phidHandle inputs indexIsInRange: portNumber ]! !

!PhdETInterfaceKit methodsFor: 'events' stamp: 'lk 7/24/2009 15:56'!
outputChange
	"This method is called if an outputValue has changed.
	We update our visible outputPorts here."
	
	self ports do: [ :port | port update: #outputPort ].! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:56'!
outputPortAvailable: portNumber

	^ phidHandle isAttached and: [ phidHandle outputs indexIsInRange: portNumber ]! !

!PhdETInterfaceKit methodsFor: 'events' stamp: 'lk 7/24/2009 15:56'!
sensorChange
	"This method is called if a sensorValue has changed.
	We update our visible sensorPorts here."
	
	self ports do: [ :port | port update: #sensorPort ].! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:57'!
sensorPortAvailable: portNumber

	^ phidHandle isAttached and: [ phidHandle sensors indexIsInRange: portNumber ]! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 7/1/2009 15:11'!
setOutput: index to: aBoolean

	(phidHandle isAttached and: [phidHandle outputs indexIsInRange: index]) ifTrue: [
		^ (phidHandle outputs at: index) value: aBoolean ].
	^ false! !

PhdETPortBasedPhidget subclass: #PhdETMotorControl
	instanceVariableNames: 'leftWheel rightWheel leftVelocityBar rightVelocityBar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETMotorControl commentStamp: 'pt 7/23/2009 17:57' prior: 0!
I am a representation of a Phidget called 'LV Motor Control' in Etoys.
You can drag me out of the objects tool in the category Phidgets.

Instance Variables
	leftVelocityBar:		a PhdETBarMorph
	leftWheel:			a PhdETWheelMorph
	rightVelocityBar:	a PhdETBarMorph
	rightWheel:			a PhdETWheelMorph

left(right)VelocityBar
	- A PhdETBarMorph that shows the current velocity of my left (right) motor.

left(right)Wheel
	- A PhdETWheelMorph that spins low or fast (or not =)) depending on the velocity of my left (right) motor.
!

!PhdETMotorControl class methodsFor: 'Etoys-Support' stamp: 'pt 7/15/2009 18:16'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		#(
			#Phidget
			#(
				#(
					#slot
					#Motor1Velocity
					'Velocity of the first attached motor. 0 means the motor is off. A Value between -100 and 100.'
					#Float
					#readWrite
					#Player
					#getMotorControlMotor1Velocity
					#Player
					#setMotorControlMotor1Velocity:
				)
				#(
					#slot
					#Motor2Velocity
					'Velocity of the second attached motor. 0 means the motor is off. A Value between -100 and 100.'
					#Float
					#readWrite
					#Player
					#getMotorControlMotor2Velocity
					#Player
					#setMotorControlMotor2Velocity:
				)
				#(
					#slot
					#Motor1Acceleration
					'Acceleration of the first attached motor. A value between MinAcceleration and MaxAcceleration.'
					#Float
					#readWrite
					#Player
					#getMotorControlMotor1Acceleration
					#Player
					#setMotorControlMotor1Acceleration:
				)
				#(
					#slot
					#Motor2Acceleration
					'Acceleration of the second attached motor. A value between MinAcceleration and MaxAcceleration.'
					#Float
					#readWrite
					#Player
					#getMotorControlMotor2Acceleration
					#Player
					#setMotorControlMotor2Acceleration:
				)
				#(
					#slot
					#MinAcceleration
					'Minimum possible Acceleration.'
					#Float
					#readOnly
					#Player
					#getMotorControlMinAcceleration
					#unused
					#unused
				)
				#(
					#slot
					#MaxAcceleration
					'Maximum possible Acceleration.'
					#Float
					#readOnly
					#Player
					#getMotorControlMaxAcceleration
					#unused
					#unused
				)
			)
		)
	)! !

!PhdETMotorControl class methodsFor: 'parts bin' stamp: 'pt 7/15/2009 13:25'!
descriptionForPartsBin
    ^ self partName:    'Motor Control'
        categories:     #('Phidgets')
        documentation:  'This Phidget controls the acceleration and velocity of two attached motors.'! !

!PhdETMotorControl class methodsFor: 'Etoys-Support' stamp: 'lk 7/24/2009 18:50'!
hasThumbnail

	^ true! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'lk 7/24/2009 15:54'!
accelerationIsInRange: aFloat 

	aFloat < self getMotorControlMinAcceleration ifTrue: [ ^ false ].
	aFloat > self getMotorControlMaxAcceleration ifTrue: [ ^ false ].
	self getMotorControlMinAcceleration == self getMotorControlMaxAcceleration ifTrue: [ ^ false ].
	^ true! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'pt 7/16/2009 16:47'!
collectPortDescriptorQuads
	"Lists the Ports I want to show."
	| quads |
	quads := OrderedCollection new.
	PhdETInputPort addPortDescriptorQuadsTo: quads.
	^ quads! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:54'!
createAndAddSubmorphs

	super createAndAddSubmorphs.

	self
		createAndAddWheels;
		createAndAddVelocityBars.! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'pt 7/16/2009 08:38'!
createAndAddVelocityBars

	leftVelocityBar := self createVelocityBar.
	rightVelocityBar := self createVelocityBar.
	self
		addMorph: rightVelocityBar;
		addMorph: leftVelocityBar.! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'pt 7/16/2009 08:36'!
createAndAddWheels

	leftWheel := self createWheel.	
	rightWheel := self createWheel.		
	self
		addMorph: rightWheel;
		addMorph: leftWheel.! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'pt 7/16/2009 08:37'!
createVelocityBar

	^  PhdETBarMorph new
		barColor: Color yellow darker;
		backColor: (Color white alpha: 0.4);
		height: 20;
		width: 60;
		minValue: -100;
		maxValue: 100;
		updateStatus;
		yourself.! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:55'!
createWheel

	^ PhdETWheelMorph new
		extent: 60 @ 60;
		speed: 0;
		minSpeed: -100;
		maxSpeed: 100;
		yourself! !

!PhdETMotorControl methodsFor: 'private' stamp: 'pt 7/16/2009 16:23'!
getInput: index

	(phidHandle isAttached and: [phidHandle inputs indexIsInRange: index]) ifTrue: [
		^ (phidHandle inputs at: index) value ].

	^ false! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/15/2009 18:08'!
getMotorControlMaxAcceleration
	"Answers the maximum possible Acceleration a Motor Control Phidget can handle."

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at:1) accelerationMax! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/15/2009 18:08'!
getMotorControlMinAcceleration
	"Answers the minimum possible Acceleration a Motor Control Phidget can handle."

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at:1) accelerationMin! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/15/2009 18:13'!
getMotorControlMotor1Acceleration
	"Returns the acceleration of motor 1 attached to a Motor Control Phidget."

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at:1) acceleration! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/15/2009 18:13'!
getMotorControlMotor1Velocity
	"Returns the velocity of motor 1 attached to a Motor Control Phidget."
	
	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at:1) velocity! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/15/2009 18:13'!
getMotorControlMotor2Acceleration
	"Returns the acceleration of motor 2 attached to a Motor Control Phidget."

	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at:2) acceleration! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/15/2009 18:13'!
getMotorControlMotor2Velocity
	"Returns the velocity of motor 1 attached to a Motor Control Phidget."
	
	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at:2) velocity! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:55'!
initialize

	self 
		initPhidget: PhdCrMotorControl new
		withLabel: 'Motor Control';
		width: 165;
		height: 195;
		positionSubmorphs.
		
	phidHandle
		on: #Attach             do: [ self updateVelocity ];
		on: #Detach             do: [ self updateVelocity ];
		on: #VelocityChange   do: [ self updateVelocity ];
		on: #InputChange      do: [ self inputChange].! !

!PhdETMotorControl methodsFor: 'events' stamp: 'pt 7/16/2009 16:11'!
inputChange
	"This method is called if an inputValue has changed.
	We update our visible inputPorts here."
	self ports do: [:port | port update: #inputPort].! !

!PhdETMotorControl methodsFor: 'port handling' stamp: 'pt 7/16/2009 17:20'!
inputPortAvailable: portNumber

	^ phidHandle isAttached and: [ phidHandle inputs indexIsInRange: portNumber ]! !

!PhdETMotorControl methodsFor: 'private' stamp: 'pt 7/16/2009 16:33'!
positionBin
		
	bin
		height: 60;
		width: 93;
		position: ((self center x - (bin width / 2)) @ (self bottom - 10 - bin height)).! !

!PhdETMotorControl methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:55'!
positionSubmorphs

	leftWheel position: self position + (15 @ 25).
	rightWheel position: leftWheel position + ((leftWheel width + 10) @ 0).
	leftVelocityBar position: leftWheel bottomLeft + (0@5).
	rightVelocityBar position: rightWheel bottomLeft + (0@5).
	self positionBin.! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/16/2009 16:38'!
setMotorControlMotor1Acceleration: aFloat 
	"Sets the acceleration of motor 1 attached to a Motor Control Phidget."
	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	(self accelerationIsInRange: aFloat) ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at: 1) acceleration: aFloat! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/16/2009 16:38'!
setMotorControlMotor1Velocity: aFloat 
	"Sets the velocity of motor 1 attached to a Motor Control Phidget."
	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	(self velocityIsInRange: aFloat) ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at: 1) velocity: aFloat! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/16/2009 16:38'!
setMotorControlMotor2Acceleration: aFloat 
	"Sets the acceleration of motor 2 attached to a Motor Control Phidget."
	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	(self accelerationIsInRange: aFloat) ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at: 2) acceleration: aFloat! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'pt 7/16/2009 16:38'!
setMotorControlMotor2Velocity: aFloat 
	"Sets the velocity of motor 2 attached to a Motor Control Phidget."
	phidHandle isAttached ifFalse: [ ^ 0.0 ].
	(self velocityIsInRange: aFloat) ifFalse: [ ^ 0.0 ].
	^ (phidHandle motors at: 2) velocity: aFloat! !

!PhdETMotorControl methodsFor: 'events' stamp: 'pt 7/15/2009 17:57'!
updateVelocity
	
	| velocity1 velocity2 |
	
	velocity1 := self getMotorControlMotor1Velocity.
	velocity2 := self getMotorControlMotor2Velocity.
	
	leftWheel speed: velocity1.
	rightWheel speed: velocity2.
	leftVelocityBar value: velocity1.
	rightVelocityBar value: velocity2.! !

!PhdETMotorControl methodsFor: 'etoys' stamp: 'lk 7/24/2009 15:55'!
velocityIsInRange: aFloat 

	aFloat < -100 ifTrue: [ ^ false ].
	aFloat > 100 ifTrue: [ ^ false ].
	^ true! !

!PhdETPortBasedPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 14:38'!
adaptSize
	"Adjusts submorphs to fit perfectly - even if I was resized."
	
	self positionBin.
	self positionLabel.! !

!PhdETPortBasedPhidget methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:58'!
createAndAddSubmorphs
	"create and add bin"
	
	super createAndAddSubmorphs.
	bin := self createBin.
	self addMorph: bin.! !

!PhdETPortBasedPhidget methodsFor: 'initialization' stamp: 'pt 5/28/2009 12:04'!
createBin
	
	| oldResizing aBin |
	aBin := (PhdETPartsBin newPartsBinWithOrientation: #leftToRight from: #())
		listDirection: #leftToRight;
		wrapDirection: #topToBottom;
		setNameTo: 'Ports';
		dropEnabled: false;
		useRoundedCorners;
		controlingMorph: self;
		yourself.

	oldResizing := aBin vResizing.
	aBin
		listDirection: #leftToRight quadList: self collectPortDescriptorQuads;
		vResizing: oldResizing;
		layoutChanged;
		fullBounds.
		
	^ aBin! !

!PhdETPortBasedPhidget methodsFor: 'submorphs-add/remove' stamp: 'lk 7/24/2009 16:01'!
delete
	"first delete all of my ports, then delete myself."

	ports reverseDo: [ :port | port delete ].
	super delete.! !

!PhdETPortBasedPhidget methodsFor: 'initialization' stamp: 'pt 5/28/2009 17:09'!
initPhidget: aPhidHandle withLabel: aLabel
	
	ports := OrderedCollection new.
	super initPhidget: aPhidHandle withLabel: aLabel.	
	bin color: self color lighter lighter.! !

!PhdETPortBasedPhidget methodsFor: 'port handling' stamp: 'lk 7/24/2009 15:58'!
ports

	^ ports! !

!PhdETPortBasedPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 17:09'!
positionBin
		
	bin
		height: self height - 20;
		top: self top + 17;
		width: self width - 6;
		left: self left + 3.! !

!PhdETPortBasedPhidget methodsFor: 'port handling' stamp: 'lk 7/24/2009 15:58'!
registerPort: aPort
	"If a new Port was dragged out of me, it registeres itself here."
	
	ports add: aPort.! !

!PhdETPortBasedPhidget methodsFor: 'port handling' stamp: 'lk 7/24/2009 15:59'!
unregisterPort: aPort
	"When a port is deleted it unregisters itself here."
	
	ports remove: aPort ifAbsent: [].! !

PhdETPhidget subclass: #PhdETServo1Motor
	instanceVariableNames: 'motorMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETServo1Motor commentStamp: 'pt 7/23/2009 17:40' prior: 0!
I am a representation of a Phidget called 'Servo 1-Motor' in Etoys.
You can drag me out of the objects tool in the category Phidgets.

Instance Variables
	motorMorph:	a PhdETServoPositionMorph

motorMorph
	- A PhdETServoPositionMorph that shows the current position of my servo motor. It also shows the minimum and maximum possible position.
!

!PhdETServo1Motor class methodsFor: 'Etoys-Support' stamp: 'pt 7/14/2009 15:31'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		#(
			#Phidget
			#(
				#(
					#slot
					#MinPosition
					'This is minimum position the servo motor can handle.'
					#Float
					#readOnly
					#Player
					#getServo1MotorMinPosition
					#unused
					#unused
				)
				#(
					#slot
					#MaxPosition
					'This is maximum position the servo motor can handle.'
					#Float
					#readOnly
					#Player
					#getServo1MotorMaxPosition
					#unused
					#unused
				)
				#(
					#slot
					#Position
					'This is the current position of the servo motor.'
					#Float
					#readWrite
					#Player
					#getServo1MotorCurrentPosition
					#Player
					#setServo1MotorCurrentPosition:
				)
				#(
					#slot
					#PositionInt
					'This is the current position of the servo motor maped as a Number between 0 and 1000.'
					#Number
					#readWrite
					#Player
					#getServo1MotorCurrentPositionNumber
					#Player
					#setServo1MotorCurrentPositionNumber:
				)
				#(
					#slot
					#Engaged
					'This is wether the servo motor is engaged or not.'
					#Boolean
					#readWrite
					#Player
					#getServo1MotorEngaged
					#Player
					#setServo1MotorEngaged:
				)
			)
		)
	)! !

!PhdETServo1Motor class methodsFor: 'parts bin' stamp: 'pt 5/29/2009 09:37'!
descriptionForPartsBin
    ^ self partName:    'Servo 1-Motor'
        categories:     #('Phidgets')
        documentation:  'A Servo Board which connects to 1 servo motor.'! !

!PhdETServo1Motor class methodsFor: 'Etoys-Support' stamp: 'lk 7/24/2009 18:50'!
hasThumbnail

	^ true! !

!PhdETServo1Motor methodsFor: 'events' stamp: 'lk 7/24/2009 15:53'!
attach
	"Sets motorMorph values for my motorMorph when I was attached."
	
	self
		setMotorMorphMin;
		setMotorMorphMax;
		setMotorMorphCurrent.! !

!PhdETServo1Motor methodsFor: 'initialization' stamp: 'pt 7/2/2009 11:52'!
createAndAddSubmorphs

	super createAndAddSubmorphs.
	motorMorph := PhdETServoPositionMorph new.
	self addMorph: motorMorph.! !

!PhdETServo1Motor methodsFor: 'events' stamp: 'pt 6/24/2009 10:01'!
detach
	"Sets motorMorph values to zero if I was attached."
	
	motorMorph
		min: 0.0;
		max: 0.0;
		current: 0.0.! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/24/2009 10:01'!
getCurrentPosition
	
	(phidHandle motors indexIsInRange: 1) ifFalse: [ ^ 0 ].
	^ (phidHandle motors at: 1) position! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'lk 6/16/2009 12:24'!
getCurrentPositionNumber
	"Calculates the motor position number relative to the intervall [0, 1000].
	aNumber=0 means that the position is set to minPosition.
	aNumber=1000 means that the position ist set to maxPosition."

	| curPosition max min |
	curPosition := self getCurrentPosition.
	max := self getMaxPosition.
	min := self getMinPosition.
	(min - max) rounded == 0 ifTrue: [ ^ 0 ].
	^ curPosition - min * 1000 / ( max - min ) rounded! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'lk 6/16/2009 12:19'!
getEngaged

	(phidHandle motors indexIsInRange: 1) ifFalse: [ ^ false ].
	^ (phidHandle motors at: 1) isEngaged! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/24/2009 10:02'!
getMaxPosition

	(phidHandle motors indexIsInRange: 1) ifFalse: [ ^ 0 ].
	^ (phidHandle motors at: 1) positionMax! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/24/2009 10:02'!
getMinPosition

	(phidHandle motors indexIsInRange: 1) ifFalse: [ ^ 0 ].
	^ (phidHandle motors at: 1) positionMin! !

!PhdETServo1Motor methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:52'!
initialize

	self 
		initPhidget: PhdCrServo new
		withLabel: 'Servo Board';
		width: 110;
		height: 83;
		initializeMotorMorph.
		
	phidHandle
		on: #Attach do: [ self attach ];
		on: #Detach do: [ self detach ];
		on: #PositionChange do: [ self positionChange ].! !

!PhdETServo1Motor methodsFor: 'initialization' stamp: 'pt 6/30/2009 12:48'!
initializeMotorMorph

	self
		setMotorMorphMin;
		setMotorMorphMax;
		setMotorMorphCurrent;
		positionMotorMorph.! !

!PhdETServo1Motor methodsFor: 'events' stamp: 'pt 6/24/2009 12:04'!
positionChange
	"Sets motorMorph position to the current position if my position changed."
	
	self setMotorMorphCurrent.! !

!PhdETServo1Motor methodsFor: 'initialization' stamp: 'pt 7/14/2009 15:18'!
positionMotorMorph

	motorMorph center: self center + (0@10).! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/24/2009 09:59'!
setCurrentPosition: aFloat

	phidHandle isAttached ifFalse: [ ^ self ].
	^ (phidHandle motors at: 1) position: aFloat! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/16/2009 14:40'!
setCurrentPositionNumber: aNumber
	"Sets the motor position to a value relative to aNumber.
	aNumber=0 means that the position is set to minPosition.
	aNumber=1000 means that the position ist set to maxPosition."

	| max min |
	( 0 <= aNumber and: [ aNumber <= 1000 ] ) ifFalse: [ ^ self ].
	max := self getMaxPosition.
	min := self getMinPosition.
	min == -1000 ifFalse: [
		self setCurrentPosition: max - min * (aNumber asFloat) / 1000.0 + min ].! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'lk 6/21/2009 12:12'!
setEngaged: aBoolean

	^ (phidHandle motors at: 1) isEngaged: aBoolean! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/24/2009 09:58'!
setMotorMorphCurrent

	motorMorph current: (self getCurrentPosition asSmallPositiveDegrees).! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/24/2009 09:58'!
setMotorMorphMax

	motorMorph max: (self getMaxPosition asSmallPositiveDegrees).! !

!PhdETServo1Motor methodsFor: 'accessing' stamp: 'pt 6/24/2009 09:58'!
setMotorMorphMin

	motorMorph min: (self getMinPosition asSmallPositiveDegrees).! !

PhdETPhidget subclass: #PhdETextLCD
	instanceVariableNames: 'row1 row2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETextLCD commentStamp: 'pt 7/23/2009 17:42' prior: 0!
I am a representation of a Phidget called 'TextLCD' in Etoys.
You can drag me out of the objects tool in the category Phidgets.

Instance Variables
	row1:	a PhdETTextLCDRowMorph
	row2:	a PhdETTextLCDRowMorph

row1
	- A PhdETTextLCDRowMorph that displays the text my Phidgets currently displays in row 1.

row2
	- Im similar to row1 (but works with row 2 of the Phidget) =)
!

!PhdETextLCD class methodsFor: 'Etoys-Support' stamp: 'pt 7/14/2009 16:09'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		#(
			#Phidget
			#(
				#(
					#slot
					#Attached
					'This is wether the Phidget is attached to the USB port or not.'
					#Boolean
					#readOnly
					#Player
					#getAttached
					#unused
					#unused
				)
				#(
					#slot
					#Rows
					'This is the number of rows the LCD can display.'
					#Number
					#readOnly
					#Player
					#getTextLCDRows
					#unused
					#unused
				)
				#(
					#slot
					#Columns
					'This is the number of columns the LCD can display.'
					#Number
					#readOnly
					#Player
					#getTextLCDColumns
					#unused
					#unused
				)
				#(
					#slot
					#Row1
					'This is the text displayed in row1.'
					#String
					#readWrite
					#Player
					#getTextLCDRow1
					#Player
					#setTextLCDRow1:
				)
				#(
					#slot
					#Row2
					'This is the text displayed in row2.'
					#String
					#readWrite
					#Player
					#getTextLCDRow2
					#Player
					#setTextLCDRow2:
				)
				#(
					#slot
					#Row1Scrolling
					'This is wether the text displayed in row1 scrolls or not.'
					#Boolean
					#readWrite
					#Player
					#getTextLCDRow1Scrolling
					#Player
					#setTextLCDRow1Scrolling:
				)
				#(
					#slot
					#Row2Scrolling
					'This is wether the text displayed in row2 scrolls or not.'
					#Boolean
					#readWrite
					#Player
					#getTextLCDRow2Scrolling
					#Player
					#setTextLCDRow2Scrolling:
				)
				#(
					#slot
					#ScrollSeperator
					'This text seperates the end of a text line and the beginning of the next text line while scrolling is active.'
					#String
					#readWrite
					#Player
					#getTextLCDScrollSeperator
					#Player
					#setTextLCDScrollSeperator:
				)
			)
		)
	)! !

!PhdETextLCD class methodsFor: 'parts bin' stamp: 'pt 7/14/2009 10:01'!
descriptionForPartsBin
    ^ self partName:    'Text LCD'
        categories:     #('Phidgets')
        documentation:  'A Phidgets that displays text on a LCD display. It shows text on 2 rows and 20 columns.'! !

!PhdETextLCD class methodsFor: 'Etoys-Support' stamp: 'lk 7/24/2009 18:50'!
hasThumbnail

	^ true! !

!PhdETextLCD methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:50'!
createAndAddSubmorphs

	super createAndAddSubmorphs.

	row1 := PhdETTextLCDRowMorph new.
	row2 := PhdETTextLCDRowMorph new.
	self
		addMorph: row1;
		addMorph: row2! !

!PhdETextLCD methodsFor: 'events' stamp: 'lk 7/24/2009 15:51'!
detach
	"When detaching, empty the row strings."

	row1 text: ''.
	row2 text: ''.! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 15:56'!
getTextLCDColumns
	"Returns the number of columnss of the Text LCD Phidget"

	phidHandle isAttached ifFalse: [ ^ 0 ].
	^ phidHandle textLCD columns! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 15:49'!
getTextLCDRow1
	"Gets the text in row1 of a Phidget TextLCD."

	phidHandle isAttached ifFalse: [ ^ '' ].
	^ phidHandle textLCD textInRow: 1! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 16:00'!
getTextLCDRow1Scrolling
	"Answers wether row1 of an TextLCD Phidget scrolls or not."

	phidHandle isAttached ifFalse: [ ^ false ].
	^ phidHandle textLCD isRowScrolling: 1! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 15:49'!
getTextLCDRow2
	"Gets the text in row2 of a Phidget TextLCD."

	phidHandle isAttached ifFalse: [ ^ '' ].
	^ phidHandle textLCD textInRow: 2! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 16:00'!
getTextLCDRow2Scrolling
	"Answers wether row2 of an TextLCD Phidget scrolls or not."

	phidHandle isAttached ifFalse: [ ^ false ].
	^ phidHandle textLCD isRowScrolling: 2! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 15:56'!
getTextLCDRows
	"Returns the number of rows of the Text LCD Phidget"

	phidHandle isAttached ifFalse: [ ^ 0 ].
	^ phidHandle textLCD rows! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 16:11'!
getTextLCDScrollSeperator
	"Returns the ScrollSeperator"
	
	phidHandle isAttached ifFalse: [ ^ '' ].
	^ phidHandle textLCD seperator! !

!PhdETextLCD methodsFor: 'initialization' stamp: 'pt 7/14/2009 17:01'!
initialize

	self 
		initPhidget: PhdCrTextLCD new withLabel: 'Text LCD';
		width: 250;
		height: 100;
		positionRows.
		
	phidHandle
		on: #Attach do: [ self updateDisplayedText ];
		on: #TextChange do: [ self updateDisplayedText ];
		on: #Detach do: [ self detach ].! !

!PhdETextLCD methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:51'!
positionRows

	row1 position: self position + (15 @ 25).
	row2 position: row1 position + (0 @ (row1 height + 5))! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 15:57'!
setTextLCDRow1: aString
	"Sets the text in row1 of a Phidget TextLCD."

	phidHandle isAttached ifFalse: [ ^ self ].
	phidHandle textLCD displayString: aString inRow: 1.! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 16:02'!
setTextLCDRow1Scrolling: aBoolean
	"Sets wether row1 of an TextLCD Phidget scrolls or not."

	phidHandle isAttached ifFalse: [ ^ self ].
	aBoolean
		ifTrue: [ phidHandle textLCD startScrollingRow: 1 ]
		ifFalse: [ phidHandle textLCD stopScrollingRow: 1 ].! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 15:57'!
setTextLCDRow2: aString
	"Sets the text in row2 of a Phidget TextLCD."

	phidHandle isAttached ifFalse: [ ^ self ].
	phidHandle textLCD displayString: aString inRow: 2.! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 16:02'!
setTextLCDRow2Scrolling: aBoolean
	"Sets wether row2 of an TextLCD Phidget scrolls or not."

	phidHandle isAttached ifFalse: [ ^ self ].
	aBoolean
		ifTrue: [ phidHandle textLCD startScrollingRow: 2 ]
		ifFalse: [ phidHandle textLCD stopScrollingRow: 2 ].! !

!PhdETextLCD methodsFor: 'etoys' stamp: 'pt 7/14/2009 16:11'!
setTextLCDScrollSeperator: aString
	"Returns the ScrollSeperator"
	
	phidHandle isAttached ifFalse: [ ^ self ].
	phidHandle textLCD seperator: aString asString.! !

!PhdETextLCD methodsFor: 'events' stamp: 'pt 7/14/2009 16:53'!
updateDisplayedText
	
	row1 text: (phidHandle textLCD displayedTextAt: 1).
	row2 text: (phidHandle textLCD displayedTextAt: 2).! !

BorderedMorph subclass: #PhdETPort
	instanceVariableNames: 'phidget portNumber numberString wire'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPort commentStamp: 'pt 7/23/2009 18:11' prior: 0!
A PhdETPort represents a PhdCrMultiComponent with the corresponding index.

Instance Variables
	numberString:	a StringMoroh
	phidget:			a PhdETPhidget
	portNumber:	an Integer
	wire:			a PolygonMorph

numberString
	- The StringMorph displaying the portNumber.

phidget
	- The PhdETPhidget I belong to.

portNumber
	- The index of the PhdCrMultiComponent I represent.

wire
	- A line (PolygonMorph) which visiualizes the connection to my belonging PhdETPhidget.
!

PhdETPort subclass: #PhdETInputPort
	instanceVariableNames: 'statusMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETInputPort commentStamp: 'pt 7/23/2009 18:14' prior: 0!
A PhdETInputPort represents a multi component PhdCrCompDigitalInput.

Instance Variables
	statusMorph:	a PhdETOnOffStatusMorph

statusMorph
	- Gives information about my state which can be on or off (true / false).
!

!PhdETInputPort class methodsFor: 'Etoys-Support' stamp: 'pt 7/23/2009 17:20'!
additionsToViewerCategoryPhidgetPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	
	^ #(
		PhidgetPort (
			(slot Value 'The value at the Digital Intput.' Boolean readOnly Player getIfKitInputValue unused unused)
		)
	)! !

!PhdETInputPort class methodsFor: 'Port handling' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Digital Input'
		categories:		#('Interface Kit')
		documentation:	'An port to a digital input of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read wether the port returns true or false.'.! !

!PhdETInputPort class methodsFor: 'Port handling' stamp: 'pt 7/23/2009 17:28'!
portType
	"Returns the type of the port. This method is called to check the port type when updating the ports appereance."
	
	^ #inputPort! !

!PhdETInputPort methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:32'!
createAndAddStatusMorph

	statusMorph := PhdETOnOffStatusMorph new.
	self addMorph: statusMorph.
	statusMorph position:
		( self width // 2 - ( statusMorph width // 2 ) ) @
		( self bottom - statusMorph height - 5 ).! !

!PhdETInputPort methodsFor: 'accessing' stamp: 'pt 6/30/2009 12:58'!
getIfKitInputValue

	^ phidget getInput: portNumber.! !

!PhdETInputPort methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:32'!
initialize

	super initialize.
	
	self
		color: Color red lighter;
		height: 70;
		createAndAddStatusMorph;
		update: self class portType.! !

!PhdETInputPort methodsFor: 'accessing' stamp: 'pt 7/16/2009 17:19'!
isInRange: aNumber
	
	^ phidget inputPortAvailable: aNumber! !

!PhdETInputPort methodsFor: 'accessing' stamp: 'pt 6/30/2009 12:59'!
setStatus: aBoolean

	statusMorph setStatus: aBoolean.! !

!PhdETInputPort methodsFor: 'updating' stamp: 'lk 7/24/2009 15:26'!
update
	"Update my appereance if my value possibly has changed."
	
	self setStatus: self getIfKitInputValue.! !

PhdETPort subclass: #PhdETOutputPort
	instanceVariableNames: 'statusMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETOutputPort commentStamp: 'pt 7/23/2009 18:15' prior: 0!
A PhdETOutputPort represents a multi component PhdCrCompDigitalOutput.

Instance Variables
	statusMorph:	a PhdETOnOffStatusMorph

statusMorph
	- Gives information about my state which can be on or off (true / false)).

!

!PhdETOutputPort class methodsFor: 'Etoys-Support' stamp: 'pt 7/23/2009 17:21'!
additionsToViewerCategoryPhidgetPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		PhidgetPort (
			(slot Value 'The value at the Digital Output.' Boolean readWrite Player getIfKitOutputValue Player setIfKitOutputValue:)
		)
	)! !

!PhdETOutputPort class methodsFor: 'Port handling' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Digital Output'
		categories:		#('Interface Kit')
		documentation:	'An port to a digital output of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read wether the port returns true or false or set this value'.! !

!PhdETOutputPort class methodsFor: 'Port handling' stamp: 'pt 7/23/2009 17:28'!
portType
	"Returns the type of the port. This method is called to check the port type when updating the ports appereance."
	
	^ #outputPort! !

!PhdETOutputPort methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:32'!
createAndAddStatusMorph

	statusMorph := PhdETOnOffStatusMorph new.
	self addMorph: statusMorph.
	statusMorph position:
		( self width // 2 - ( statusMorph width // 2 ) ) @
		( self bottom - statusMorph height - 5 ).! !

!PhdETOutputPort methodsFor: 'accessing' stamp: 'pt 6/30/2009 12:53'!
getIfKitOutputValue

	^ phidget getOutput: portNumber.! !

!PhdETOutputPort methodsFor: 'initialization' stamp: 'pt 7/2/2009 17:03'!
initialize
	super initialize.
	self
		color: Color blue muchLighter;
		height: 70;
		createAndAddStatusMorph;
		update: self class portType.! !

!PhdETOutputPort methodsFor: 'accessing' stamp: 'pt 6/2/2009 10:35'!
isInRange: aNumber
	
	^ phidget outputPortAvailable: aNumber! !

!PhdETOutputPort methodsFor: 'accessing' stamp: 'pt 6/30/2009 12:53'!
setIfKitOutputValue: aBoolean

	^ phidget setOutput: portNumber to: aBoolean.! !

!PhdETOutputPort methodsFor: 'accessing' stamp: 'pt 6/30/2009 12:59'!
setStatus: aBoolean

	statusMorph setStatus: aBoolean.! !

!PhdETOutputPort methodsFor: 'updating' stamp: 'lk 7/24/2009 15:30'!
update
	"Update my appereance if my value possibly has changed."

	self setStatus: self getIfKitOutputValue.! !

!PhdETPort class methodsFor: 'PartsBin' stamp: 'pt 5/7/2009 08:17'!
addPortDescriptorQuadsTo: aList
	"analogous to addPartsDescriptorQuadsTo: aList if: aBlock from the Morph class"
	
	| info |
	info := self portDescription.
	aList add:
		{info globalReceiverSymbol.
		info nativitySelector.
		info formalName.
		info documentation.
		info sampleImageFormOrNil}.! !

!PhdETPort class methodsFor: 'Etoys-Support' stamp: 'pt 7/23/2009 17:20'!
additionsToViewerCategoryPhidgetPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		PhidgetPort (
			(slot PortNumber 'The index of this Port.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this Port to its Phidget is shown.' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETPort class methodsFor: 'PartsBin' stamp: 'pt 5/7/2009 12:00'!
launchPartVia: aSelector label: aString phidget: aPhidget
	"Obtain a morph by sending aSelector to self, and attach it to the morphic hand.  This provides a general protocol for parts bins"

	| aMorph |
	aMorph := self perform: aSelector with: aPhidget.
	aMorph setNameTo: (ActiveWorld unusedMorphNameLike: aString).
	aMorph setProperty: #beFullyVisibleAfterDrop toValue: true.
	aMorph openInHand! !

!PhdETPort class methodsFor: 'PartsBin' stamp: 'pt 5/7/2009 10:54'!
newStandAlone: aPhidget
	"Answer an instance capable of standing by itself as a usable morph."

	^ self basicNew initializeToStandAlone: aPhidget! !

!PhdETPort class methodsFor: 'PartsBin' stamp: 'pt 5/7/2009 10:52'!
partName: aName categories: aList documentation: aDoc
	"Answer a DescriptionForPartsBin which will represent a launch of a new instance of my class via the #newStandAlone protocol sent to my class. Use the category-list and documentation provided"


	^ DescriptionForPartsBin new
		formalName: aName
		categoryList: aList
		documentation: aDoc
		globalReceiverSymbol: self name
		nativitySelector: #newStandAlone:! !

!PhdETPort class methodsFor: 'Port handling' stamp: 'pt 5/7/2009 08:18'!
portDescription

	self subclassResponsibility.
	! !

!PhdETPort class methodsFor: 'Port handling' stamp: 'pt 7/24/2009 14:22'!
portType
	"Returns the type of the port. This method is called to check the port type when updating the ports appereance."
	
	^ #abstractPort! !

!PhdETPort methodsFor: 'animation' stamp: 'lk 7/24/2009 15:34'!
centerNumberString

	| stringCenter topMiddle |
	topMiddle := (self width // 2) @ 15.
	stringCenter :=
		(numberString width / 2) @
		( numberString height / 2).
	numberString position: self position + topMiddle - stringCenter.! !

!PhdETPort methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:36'!
createWire

	wire := LineMorph new.
	self currentWorld addMorphBack: wire.! !

!PhdETPort methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:40'!
delete
	"When deleting, first unregister the port from the phidget and delete the TransformMorph (if any)."

	wire delete.
	phidget unregisterPort: self.
	(self owner isKindOf: TransformMorph) ifTrue: [owner delete].
	super delete.! !

!PhdETPort methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:35'!
getPortNumber

	^ portNumber! !

!PhdETPort methodsFor: 'accessing' stamp: 'pt 7/23/2009 17:23'!
getShowWire
	"This is wether the wire from me to my phidget is shown or not."
	
	^ wire visible! !

!PhdETPort methodsFor: 'initialization' stamp: 'pt 6/30/2009 13:05'!
initialize
	super initialize.
	self useRoundedCorners.
	portNumber := 1.
	numberString := (StringMorph new
							contents: portNumber asString;
							emphasis: 1;
							yourself).
	self
		centerNumberString;
		addMorph: numberString.! !

!PhdETPort methodsFor: 'initialization' stamp: 'pt 6/2/2009 10:34'!
initializeToStandAlone: aPhidget
	phidget := aPhidget.
	phidget registerPort: self.
	self initialize.
	! !

!PhdETPort methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:35'!
isInRange: aNumber
	"A subclass may override this, to allow changing portNumbers"
	
	^ false! !

!PhdETPort methodsFor: 'animation' stamp: 'lk 7/24/2009 15:36'!
positionWire
	"Positions the Wire so that it reaches from the origin Phidgits to me. If the Wire doenstn exists, create it."

	"Cannot create Wire while initialisation, because that ruins my Thumbnail. So I do it here."
	wire ifNil: [ self createWire ].
	wire setVertices: {
		phidget referencePositionInWorld.
		self referencePositionInWorld }.! !

!PhdETPort methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:35'!
setPortNumber: aNumber

	( aNumber isInteger and: [ self isInRange: aNumber ] )
	ifTrue: [
		portNumber := aNumber.
		numberString contents: portNumber asString.
		self centerNumberString.
		self update: self class portType ]! !

!PhdETPort methodsFor: 'accessing' stamp: 'pt 7/23/2009 17:23'!
setShowWire: aBoolean
	"This is wether the wire from me to my phidget is shown or not."
	
	^ wire visible: aBoolean! !

!PhdETPort methodsFor: 'animation' stamp: 'lk 7/24/2009 15:35'!
step

	self positionWire.! !

!PhdETPort methodsFor: 'animation' stamp: 'lk 7/24/2009 15:35'!
stepTime

	^ 100! !

!PhdETPort methodsFor: 'updating' stamp: 'lk 7/24/2009 15:29'!
update
	"This method is called from update if my port type matches the type of all port to be updated.
	Subclasses should override this method if they need to update their state."! !

!PhdETPort methodsFor: 'updating' stamp: 'lk 7/24/2009 15:29'!
update: type
	"This method is called if a value of the phidget I belong has changed.
	This gives me the opportunity to update my appereance if the given type matches mine."

	type = self class portType ifTrue: [ self update ].! !

PhdETPort subclass: #PhdETSensorPort
	instanceVariableNames: 'statusMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETSensorPort commentStamp: 'pt 7/23/2009 18:17' prior: 0!
A PhdETSensorPort represents a multi component PhdCrCompAnalogSensor.

Instance Variables
	statusMorph:	a PhdETPositiveBarMorph

statusMorph
	- Gives information about my value state which can be a value between 0 and 1000.

!

!PhdETSensorPort class methodsFor: 'Etoys-Support' stamp: 'pt 7/23/2009 17:21'!
additionsToViewerCategoryPhidgetPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		PhidgetPort (
			(slot Value 'The value at the Analog Sensor (0 - 1000).' Number readOnly Player getIfKitSensorValue unused unused)
		)
	)! !

!PhdETSensorPort class methodsFor: 'Port handling' stamp: 'pt 7/23/2009 17:28'!
portDescription

	^  self
		partName:		'Analog Sensor'
		categories:		#('Interface Kit')
		documentation:	'An port to an Analog Sensor of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read which value an attached Analog Sensor returns. This value is between 0 and 1000.'.! !

!PhdETSensorPort class methodsFor: 'Port handling' stamp: 'pt 7/23/2009 17:28'!
portType
	"Returns the type of the port. This method is called to check the port type when updating the ports appereance."
	
	^ #sensorPort! !

!PhdETSensorPort methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:23'!
createAndAddStatusMorph

	statusMorph := PhdETPositiveBarMorph new.
	self addMorph: statusMorph.
	statusMorph
		width: self width - 10;
		height: 20;
		position:
			(self width // 2 - (statusMorph width // 2)) @
			(self bottom - statusMorph height - 5)! !

!PhdETSensorPort methodsFor: 'accessing' stamp: 'lk 7/24/2009 15:22'!
getIfKitSensorValue

	^ phidget getSensor: portNumber! !

!PhdETSensorPort methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:23'!
initialize

	super initialize.
	self
		color: Color yellow lighter;
		height: 50;
		width: 100;
		createAndAddStatusMorph;
		update: self class portType;
		centerNumberString.! !

!PhdETSensorPort methodsFor: 'accessing' stamp: 'pt 7/16/2009 17:20'!
isInRange: aNumber
	
	^ phidget sensorPortAvailable: aNumber! !

!PhdETSensorPort methodsFor: 'accessing' stamp: 'pt 7/2/2009 17:01'!
setStatus: aNumber

	statusMorph value: aNumber.! !

!PhdETSensorPort methodsFor: 'updating' stamp: 'lk 7/24/2009 15:30'!
update
	"Update my appereance if my value possibly has changed."

	self setStatus: self getIfKitSensorValue.! !

BorderedMorph subclass: #PhdETTextLCDRowMorph
	instanceVariableNames: 'textMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETTextLCDRowMorph commentStamp: 'pt 7/24/2009 12:07' prior: 0!
A PhdETTextLCDRowMorph represents a row of a Text LCD Phidget.

Instance Variables
	textMorph:	a StringMorph

textMorph
	- A String Morph holding the text that is currently displayed.
!

!PhdETTextLCDRowMorph methodsFor: 'initialization' stamp: 'pt 7/14/2009 15:03'!
initTextMorph

	textMorph
		position: self position + (10@6);
		font: (TTCFont family: 'BitstreamVeraSansMono' size: 15);
		emphasis: 1.! !

!PhdETTextLCDRowMorph methodsFor: 'initialization' stamp: 'lk 7/24/2009 15:07'!
initialize

	super initialize.
	textMorph := StringMorph new.
	self
		addMorph: textMorph;
		color: (Color white alpha: 0.5);
		height: 30;
		width: 220;
		text: '01234567890123456789'. "initialise with a sample text. it will be erased when the phidget gets attached."
		
	self initTextMorph.! !

!PhdETTextLCDRowMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 12:08'!
text

	^ textMorph contents! !

!PhdETTextLCDRowMorph methodsFor: 'accessing' stamp: 'pt 7/24/2009 12:08'!
text: aString

	textMorph contents: aString asString.! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getAcclRotationAroundX
	"Answers the current Rotation around the x-axis of an 3-axis accelerometer."

	^ self targetMorph getAcclRotationAroundX! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getAcclRotationAroundXNumber
	"Answers the current Rotation around the x-axis of an 3-axis accelerometer - mapped to a number between 0 and 1000."

	^ self targetMorph getAcclRotationAroundXNumber! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getAcclRotationAroundY
	"Answers the current Rotation around the y-axis of an 3-axis accelerometer."

	^ self targetMorph getAcclRotationAroundY! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getAcclRotationAroundYNumber
	"Answers the current Rotation around the y-axis of an 3-axis accelerometer - mapped to a number between 0 and 1000."

	^ self targetMorph getAcclRotationAroundYNumber! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getAcclRotationAroundZ
	"Answers the current Rotation around the z-axis of an 3-axis accelerometer."

	^ self targetMorph getAcclRotationAroundZ! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getAcclRotationAroundZNumber
	"Answers the current Rotation around the z-axis of an 3-axis accelerometer - mapped to a number between 0 and 1000."

	^ self targetMorph getAcclRotationAroundZNumber! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getAttached
	"Answers wether an Interface Kit is attached or not."

	^ self targetMorph getAttached! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getIfKitInputValue
	"Answer the value of an Interface Kits digital input."

	^ self targetMorph getIfKitInputValue! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:50'!
getIfKitOutputValue
	"Answer the value of an Interface Kits digital output."

	^ self targetMorph getIfKitOutputValue! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/23/2009 17:26'!
getIfKitSensorValue
	"Answer the value of an Interface Kits analog sensor."
	
	^ self targetMorph getIfKitSensorValue! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
getLabel
	"Answers the label of a Phidget"

	^ self targetMorph getLabel! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:13'!
getMotorControlMaxAcceleration
	"Answers the maximum possible Acceleration a Motor Control Phidget can handle."

	^ self targetMorph getMotorControlMaxAcceleration! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:13'!
getMotorControlMinAcceleration
	"Answers the minimum possible Acceleration a Motor Control Phidget can handle."

	^ self targetMorph getMotorControlMinAcceleration! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:21'!
getMotorControlMotor1Acceleration
	"Returns the acceleration of motor 1 attached to a Motor Control Phidget."

	^ self targetMorph getMotorControlMotor1Acceleration! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:40'!
getMotorControlMotor1Velocity
	"Returns the velocity of motor 1 attached to a Motor Control Phidget."

	^ self targetMorph getMotorControlMotor1Velocity! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:22'!
getMotorControlMotor2Acceleration
	"Returns the acceleration of motor 2 attached to a Motor Control Phidget."

	^ self targetMorph getMotorControlMotor2Acceleration! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:41'!
getMotorControlMotor2Velocity
	"Returns the velocity of motor 2 attached to a Motor Control Phidget."

	^ self targetMorph getMotorControlMotor2Velocity! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/23/2009 17:26'!
getPortNumber
	"Answers the index of a Phidget port."

	^ self targetMorph getPortNumber! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
getServo1MotorCurrentPosition
	"Get the servo motors positio in the intervall [0,10000]."

	^ self targetMorph getCurrentPosition! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
getServo1MotorCurrentPositionNumber
	"Get the servo motors position."

	^ self targetMorph getCurrentPositionNumber! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
getServo1MotorEngaged
	"This is wether the motor is engaged or not"

	^ self targetMorph getEngaged! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
getServo1MotorMaxPosition
	"Get the servo maximum position."
	
	^ self targetMorph getMaxPosition! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
getServo1MotorMinPosition
	"Get the servo minimum position."
	
	^ self targetMorph getMinPosition! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/23/2009 17:16'!
getShowWire
	"Get visible state of the wire between a port and its phidget.."
	
	^ self targetMorph getShowWire! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:55'!
getTextLCDColumns
	"Returns the number of columns of a Text LCD Phidget."
	
	^ self targetMorph getTextLCDColumns! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:40'!
getTextLCDRow1
	"Sets the text in row1 of a Phidget TextLCD."

	^ self targetMorph getTextLCDRow1! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:38'!
getTextLCDRow1Scrolling
	"Answers wether row1 of an TextLCD Phidget scrolls or not."

	^ self targetMorph getTextLCDRow1Scrolling! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:40'!
getTextLCDRow2
	"Sets the text in row2 of a Phidget TextLCD."

	^ self targetMorph getTextLCDRow2! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:38'!
getTextLCDRow2Scrolling
	"Answers wether row2 of an TextLCD Phidget scrolls or not."

	^ self targetMorph getTextLCDRow2Scrolling! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:55'!
getTextLCDRows
	"Returns the number of rows of a Text LCD Phidget."
	
	^ self targetMorph getTextLCDRows! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 16:09'!
getTextLCDScrollSeperator
	"Returns the scroll Seperator."
	
	^ self targetMorph getTextLCDScrollSeperator! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
setIfKitOutputValue: value
	"Set the value of a Phidget Port"

	^ self targetMorph setIfKitOutputValue: value! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:51'!
setLabel: anObject
	"Sets the label of a Phidget"

	^ self targetMorph setLabel: anObject! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:18'!
setMotorControlMotor1Acceleration: aFloat
	"Sets the acceleration of motor 1 attached to a Motor Control Phidget."

	^ self targetMorph setMotorControlMotor1Acceleration: aFloat! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:42'!
setMotorControlMotor1Velocity: aFloat
	"Sets the velocity of motor 1 attached to a Motor Control Phidget."

	^ self targetMorph setMotorControlMotor1Velocity: aFloat! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:18'!
setMotorControlMotor2Acceleration: aFloat
	"Sets the acceleration of motor 2 attached to a Motor Control Phidget."

	^ self targetMorph setMotorControlMotor2Acceleration: aFloat! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/15/2009 15:41'!
setMotorControlMotor2Velocity: aFloat
	"Sets the velocity of motor 2 attached to a Motor Control Phidget."

	^ self targetMorph setMotorControlMotor2Velocity: aFloat! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:52'!
setPortNumber: aNumber
	"Answers the index of a Phidget port."

	^ self targetMorph setPortNumber: aNumber! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:52'!
setServo1MotorCurrentPosition: aFloat 
	"Set the servo motors position."
	
	^ self targetMorph setCurrentPosition: aFloat! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:52'!
setServo1MotorCurrentPositionNumber: aNumber 
	"Set the servo motors position in an Intervall of 0 to 10,000"
	
	^ self targetMorph setCurrentPositionNumber: aNumber! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/3/2009 13:52'!
setServo1MotorEngaged: aBoolean 
	"This is wether the motor is engaged or not"
	
	^ self targetMorph setEngaged: aBoolean! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/23/2009 17:16'!
setShowWire: aBoolean 
	"Set visible state of the wire between a port and its phidget.."
	
	^ self targetMorph setShowWire: aBoolean! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:40'!
setTextLCDRow1: aString
	"Sets the text in row1 of a Phidget TextLCD."

	^ self targetMorph setTextLCDRow1: aString! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:39'!
setTextLCDRow1Scrolling: aBoolean
	"Sets wether row1 of an TextLCD Phidget scrolls or not."

	^ self targetMorph setTextLCDRow1Scrolling: aBoolean! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:58'!
setTextLCDRow2: aString
	"Sets the text in row2 of a Phidget TextLCD."

	^ self targetMorph setTextLCDRow2: aString! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 15:39'!
setTextLCDRow2Scrolling: aBoolean
	"Sets wether row2 of an TextLCD Phidget scrolls or not."

	^ self targetMorph setTextLCDRow2Scrolling: aBoolean! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/14/2009 16:10'!
setTextLCDScrollSeperator: aString
	"Sets the scroll Seperator."
	
	^ self targetMorph setTextLCDScrollSeperator: aString! !

!Player methodsFor: '*Phidget-EToys' stamp: 'pt 7/23/2009 17:26'!
targetMorph
	"if the my costume is a TransformationMorph (-> the original Morph was rotated) don't return "
	
	(self costume isKindOf: TransformationMorph) ifTrue: [ ^ self costume renderedMorph ].
	^ self costume! !
